.. _examples:

======================
Examples
======================

.. toctree::
   :maxdepth: 1

   flattening_and_folding_psd_matrix.ipynb
   optimizing_psd_matrix.ipynb
   flattening_and_folding_free_default.ipynb
   parameter_containers.ipynb
   optimization_class.ipynb
